@@ -42,6 +42,7 @@
 #include <sys/types.h>
 #include <apt-pkg/error.h>
 #include <apt-pkg/configuration.h>
+#include <apt-pkg/install-progress.h>
 #include <apt-pkg/pkgsystem.h>
 #include <cassert>
 #include <cstring>
@@ -60,6 +61,10 @@ RGTermInstallProgress::RGTermInstallProgress(RGMainWindow *main)
 {
    setTitle(_("Applying Changes"));
 
+   // make sure we try to get a graphical debconf
+   putenv("DEBIAN_FRONTEND=gnome");
+   putenv("APT_LISTCHANGES_FRONTEND=gtk");
+
    _term = vte_terminal_new();
    vte_terminal_set_size(VTE_TERMINAL(_term),80,23);
    _scrollbar = gtk_scrollbar_new (GTK_ORIENTATION_VERTICAL,
@@ -67,9 +72,9 @@ RGTermInstallProgress::RGTermInstallProgress(RGMainWindow *main)
    gtk_widget_set_can_focus (_scrollbar, FALSE);
    vte_terminal_set_scrollback_lines(VTE_TERMINAL(_term), 10000);
 
-   char *s;
+   const char *s;
    if(_config->FindB("Synaptic::useUserTerminalFont")) {
-      char *s =(char*)_config->Find("Synaptic::TerminalFontName").c_str();
+      s = _config->Find("Synaptic::TerminalFontName").c_str();
    } else {
       s = "monospace 10";
    }
@@ -120,24 +125,7 @@ void RGTermInstallProgress::startUpdate()
 		    G_CALLBACK(child_exited),
 		    this);
  
-   // check if we run embedded
-   int id = _config->FindI("Volatile::PlugProgressInto", -1);
-   //cout << "Plug ID: " << id << endl;
-   if (id > 0) {
-#if !GTK_CHECK_VERSION(3,0,0)
-      gtk_widget_hide(GTK_WIDGET(gtk_builder_get_object
-                                 (_builder, "window_zvtinstallprogress")));
-      GtkWidget *vbox = GTK_WIDGET(gtk_builder_get_object
-                                   (_builder, "vbox_terminstall_progress"));
-      _sock =  gtk_plug_new(id);
-      gtk_widget_reparent(vbox, _sock);
-      gtk_widget_show(_sock);
-#else
-      g_error("gtk_plugin_new not supported with gtk3");
-#endif
-   } else {
-      show();
-   }
+   show();
 
    gtk_label_set_markup(GTK_LABEL(_statusL), _("<i>Running...</i>"));
    gtk_widget_set_sensitive(_closeB, false);
@@ -240,7 +228,8 @@ RGTermInstallProgress::start(pkgPackageManager *pm,
       memset( &new_act, 0, sizeof( new_act ) );
       new_act.sa_handler = SIG_IGN;
       sigaction( SIGPIPE, &new_act, NULL);
-      res = pm->DoInstallPostFork();
+      APT::Progress::PackageManagerProgressFd progress(-1);
+      res = pm->DoInstallPostFork(&progress);
       _exit(res);
    }
    // parent: assign pty to the vte terminal
